@@ -114,7 +114,7 @@ Channel::Channel(TQWidget* parent, TQString _name) : ChatWindow(parent)
     TQSizePolicy modest = TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Preferred);
     TQSizePolicy greedy = TQSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
 
-    m_vertSplitter = new TQSplitter(Qt::Vertical, this);
+    m_vertSplitter = new TQSplitter(TQt::Vertical, this);
     m_vertSplitter->setOpaqueResize(TDEGlobalSettings::opaqueResize());
 
 
@@ -126,13 +126,13 @@ Channel::Channel(TQWidget* parent, TQString _name) : ChatWindow(parent)
     m_topicButton = new TQToolButton(topicWidget);
     m_topicButton->setIconSet(SmallIconSet("edit", 16));
     TQToolTip::add(m_topicButton, i18n("Edit Channel Settings"));
-    connect(m_topicButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(showOptionsDialog()));
+    connect(m_topicButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(showOptionsDialog()));
 
     topicLine = new Konversation::TopicLabel(topicWidget);
     TQWhatsThis::add(topicLine, i18n("<qt>Every channel on IRC has a topic associated with it.  This is simply a message that everybody can see.<p>If you are an operator, or the channel mode <em>'T'</em> has not been set, then you can change the topic by clicking the Edit Channel Properties button to the left of the topic.  You can also view the history of topics there.</qt>"));
-    connect(topicLine, TQT_SIGNAL(setStatusBarTempText(const TQString&)), this, TQT_SIGNAL(setStatusBarTempText(const TQString&)));
-    connect(topicLine, TQT_SIGNAL(clearStatusBarTempText()), this, TQT_SIGNAL(clearStatusBarTempText()));
-    connect(topicLine,TQT_SIGNAL(popupCommand(int)),this,TQT_SLOT(popupChannelCommand(int)));
+    connect(topicLine, TQ_SIGNAL(setStatusBarTempText(const TQString&)), this, TQ_SIGNAL(setStatusBarTempText(const TQString&)));
+    connect(topicLine, TQ_SIGNAL(clearStatusBarTempText()), this, TQ_SIGNAL(clearStatusBarTempText()));
+    connect(topicLine,TQ_SIGNAL(popupCommand(int)),this,TQ_SLOT(popupChannelCommand(int)));
 
     topicLayout->addWidget(m_topicButton, 0, 0);
     topicLayout->addMultiCellWidget(topicLine, 0, 1, 1, 1);
@@ -158,20 +158,20 @@ Channel::Channel(TQWidget* parent, TQString _name) : ChatWindow(parent)
     TQWhatsThis::add(modeK, i18n("<qt>These control the <em>mode</em> of the channel.  Only an operator can change these.<p>A <b>P</b>rotected channel requires users to enter a password in order to join.</qt>"));
     TQWhatsThis::add(modeL, i18n("<qt>These control the <em>mode</em> of the channel.  Only an operator can change these.<p>A channel that has a user <b>L</b>imit means that only that many users can be in the channel at any one time.  Some channels have a bot that sits in the channel and changes this automatically depending on how busy the channel is.</qt>"));
 
-    connect(modeT,TQT_SIGNAL(clicked(int,bool)),this,TQT_SLOT(modeButtonClicked(int,bool)));
-    connect(modeN,TQT_SIGNAL(clicked(int,bool)),this,TQT_SLOT(modeButtonClicked(int,bool)));
-    connect(modeS,TQT_SIGNAL(clicked(int,bool)),this,TQT_SLOT(modeButtonClicked(int,bool)));
-    connect(modeI,TQT_SIGNAL(clicked(int,bool)),this,TQT_SLOT(modeButtonClicked(int,bool)));
-    connect(modeP,TQT_SIGNAL(clicked(int,bool)),this,TQT_SLOT(modeButtonClicked(int,bool)));
-    connect(modeM,TQT_SIGNAL(clicked(int,bool)),this,TQT_SLOT(modeButtonClicked(int,bool)));
-    connect(modeK,TQT_SIGNAL(clicked(int,bool)),this,TQT_SLOT(modeButtonClicked(int,bool)));
-    connect(modeL,TQT_SIGNAL(clicked(int,bool)),this,TQT_SLOT(modeButtonClicked(int,bool)));
+    connect(modeT,TQ_SIGNAL(clicked(int,bool)),this,TQ_SLOT(modeButtonClicked(int,bool)));
+    connect(modeN,TQ_SIGNAL(clicked(int,bool)),this,TQ_SLOT(modeButtonClicked(int,bool)));
+    connect(modeS,TQ_SIGNAL(clicked(int,bool)),this,TQ_SLOT(modeButtonClicked(int,bool)));
+    connect(modeI,TQ_SIGNAL(clicked(int,bool)),this,TQ_SLOT(modeButtonClicked(int,bool)));
+    connect(modeP,TQ_SIGNAL(clicked(int,bool)),this,TQ_SLOT(modeButtonClicked(int,bool)));
+    connect(modeM,TQ_SIGNAL(clicked(int,bool)),this,TQ_SLOT(modeButtonClicked(int,bool)));
+    connect(modeK,TQ_SIGNAL(clicked(int,bool)),this,TQ_SLOT(modeButtonClicked(int,bool)));
+    connect(modeL,TQ_SIGNAL(clicked(int,bool)),this,TQ_SLOT(modeButtonClicked(int,bool)));
 
     limit=new KLineEdit(modeBox);
     TQToolTip::add(limit, i18n("Maximum users allowed in channel"));
     TQWhatsThis::add(limit, i18n("<qt>This is the channel user limit - the maximum number of users that can be in the channel at a time.  If you are an operator, you can set this.  The channel mode <b>T</b>opic (button to left) will automatically be set if set this.</qt>"));
-    connect(limit,TQT_SIGNAL (returnPressed()),this,TQT_SLOT (channelLimitChanged()) );
-    connect(limit,TQT_SIGNAL (lostFocus()), this, TQT_SLOT(channelLimitChanged()) );
+    connect(limit,TQ_SIGNAL (returnPressed()),this,TQ_SLOT (channelLimitChanged()) );
+    connect(limit,TQ_SIGNAL (lostFocus()), this, TQ_SLOT(channelLimitChanged()) );
 
     topicLayout->addWidget(modeBox, 0, 2);
     topicLayout->setRowStretch(1, 10);
@@ -187,8 +187,8 @@ Channel::Channel(TQWidget* parent, TQString _name) : ChatWindow(parent)
     // Server will be set later in setServer()
     IRCViewBox* ircViewBox = new IRCViewBox(m_horizSplitter, NULL);
     setTextView(ircViewBox->ircView());
-    connect(textView,TQT_SIGNAL(popupCommand(int)),this,TQT_SLOT(popupChannelCommand(int)));
-    connect(topicLine, TQT_SIGNAL(currentChannelChanged(const TQString&)),textView,TQT_SLOT(setCurrentChannel(const TQString&)));
+    connect(textView,TQ_SIGNAL(popupCommand(int)),this,TQ_SLOT(popupChannelCommand(int)));
+    connect(topicLine, TQ_SIGNAL(currentChannelChanged(const TQString&)),textView,TQ_SLOT(setCurrentChannel(const TQString&)));
 
     // The box that holds the Nick List and the quick action buttons
     nickListButtons = new TQVBox(m_horizSplitter);
@@ -268,57 +268,57 @@ Channel::Channel(TQWidget* parent, TQString _name) : ChatWindow(parent)
     getTextView()->setSizePolicy(greedy);
     nicknameListView->setSizePolicy(hmodest);
 
-    connect(channelInput,TQT_SIGNAL (submit()),this,TQT_SLOT (channelTextEntered()) );
-    connect(channelInput,TQT_SIGNAL (envelopeCommand()),this,TQT_SLOT (channelPassthroughCommand()) );
-    connect(channelInput,TQT_SIGNAL (nickCompletion()),this,TQT_SLOT (completeNick()) );
-    connect(channelInput,TQT_SIGNAL (endCompletion()),this,TQT_SLOT (endCompleteNick()) );
-    connect(channelInput,TQT_SIGNAL (textPasted(const TQString&)),this,TQT_SLOT (textPasted(const TQString&)) );
+    connect(channelInput,TQ_SIGNAL (submit()),this,TQ_SLOT (channelTextEntered()) );
+    connect(channelInput,TQ_SIGNAL (envelopeCommand()),this,TQ_SLOT (channelPassthroughCommand()) );
+    connect(channelInput,TQ_SIGNAL (nickCompletion()),this,TQ_SLOT (completeNick()) );
+    connect(channelInput,TQ_SIGNAL (endCompletion()),this,TQ_SLOT (endCompleteNick()) );
+    connect(channelInput,TQ_SIGNAL (textPasted(const TQString&)),this,TQ_SLOT (textPasted(const TQString&)) );
 
-    connect(getTextView(), TQT_SIGNAL(textPasted(bool)), channelInput, TQT_SLOT(paste(bool)));
-    connect(getTextView(),TQT_SIGNAL (gotFocus()),channelInput,TQT_SLOT (setFocus()) );
-    connect(getTextView(),TQT_SIGNAL (sendFile()),this,TQT_SLOT (sendFileMenu()) );
-    connect(getTextView(),TQT_SIGNAL (autoText(const TQString&)),this,TQT_SLOT (sendChannelText(const TQString&)) );
+    connect(getTextView(), TQ_SIGNAL(textPasted(bool)), channelInput, TQ_SLOT(paste(bool)));
+    connect(getTextView(),TQ_SIGNAL (gotFocus()),channelInput,TQ_SLOT (setFocus()) );
+    connect(getTextView(),TQ_SIGNAL (sendFile()),this,TQ_SLOT (sendFileMenu()) );
+    connect(getTextView(),TQ_SIGNAL (autoText(const TQString&)),this,TQ_SLOT (sendChannelText(const TQString&)) );
 
-    connect(nicknameListView,TQT_SIGNAL (popupCommand(int)),this,TQT_SLOT (popupCommand(int)) );
-    connect(nicknameListView,TQT_SIGNAL (doubleClicked(TQListViewItem*)),this,TQT_SLOT (doubleClickCommand(TQListViewItem*)) );
-    connect(nicknameListView,TQT_SIGNAL (dropped(TQDropEvent*,TQListViewItem*)),this,TQT_SLOT (filesDropped(TQDropEvent*)) );
-    connect(nicknameCombobox,TQT_SIGNAL (activated(int)),this,TQT_SLOT(nicknameComboboxChanged()));
+    connect(nicknameListView,TQ_SIGNAL (popupCommand(int)),this,TQ_SLOT (popupCommand(int)) );
+    connect(nicknameListView,TQ_SIGNAL (doubleClicked(TQListViewItem*)),this,TQ_SLOT (doubleClickCommand(TQListViewItem*)) );
+    connect(nicknameListView,TQ_SIGNAL (dropped(TQDropEvent*,TQListViewItem*)),this,TQ_SLOT (filesDropped(TQDropEvent*)) );
+    connect(nicknameCombobox,TQ_SIGNAL (activated(int)),this,TQ_SLOT(nicknameComboboxChanged()));
 
     if(nicknameCombobox->lineEdit())
-        connect(nicknameCombobox->lineEdit(), TQT_SIGNAL (lostFocus()),this,TQT_SLOT(nicknameComboboxChanged()));
+        connect(nicknameCombobox->lineEdit(), TQ_SIGNAL (lostFocus()),this,TQ_SLOT(nicknameComboboxChanged()));
 
     nicknameList.setAutoDelete(true);
 
     setLog(Preferences::log());
 
-    connect(&userhostTimer,TQT_SIGNAL (timeout()),this,TQT_SLOT (autoUserhost()));
+    connect(&userhostTimer,TQ_SIGNAL (timeout()),this,TQ_SLOT (autoUserhost()));
 
     // every few seconds try to get more userhosts
     userhostTimer.start(10000);
 
-    connect(&m_whoTimer,TQT_SIGNAL (timeout()),this,TQT_SLOT (autoWho()));
+    connect(&m_whoTimer,TQ_SIGNAL (timeout()),this,TQ_SLOT (autoWho()));
 
     // every 5 minutes decrease everyone's activity by 1 unit
     m_fadeActivityTimer.start(5*60*1000);
     
-    connect(&m_fadeActivityTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(fadeActivity()));
+    connect(&m_fadeActivityTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(fadeActivity()));
 
     // re-schedule when the settings were changed
-    connect(Preferences::self(), TQT_SIGNAL (autoContinuousWhoChanged()),this,TQT_SLOT (scheduleAutoWho()));
+    connect(Preferences::self(), TQ_SIGNAL (autoContinuousWhoChanged()),this,TQ_SLOT (scheduleAutoWho()));
 
     updateAppearance();
 
     //FIXME JOHNFLUX
-    //  connect( Konversation::Addressbook::self()->getAddressBook(), TQT_SIGNAL( addressBookChanged( AddressBook * ) ), this, TQT_SLOT( slotLoadAddressees() ) );
-    //  connect( Konversation::Addressbook::self(), TQT_SIGNAL(addresseesChanged()), this, TQT_SLOT(slotLoadAddressees()));
+    //  connect( Konversation::Addressbook::self()->getAddressBook(), TQ_SIGNAL( addressBookChanged( AddressBook * ) ), this, TQ_SLOT( slotLoadAddressees() ) );
+    //  connect( Konversation::Addressbook::self(), TQ_SIGNAL(addresseesChanged()), this, TQ_SLOT(slotLoadAddressees()));
 }
 
 //FIXME there is some logic in setLogfileName that needs to be split out and called here if the server display name gets changed
 void Channel::setServer(Server* server)
 {
     if (m_server != server)
-        connect(server, TQT_SIGNAL(connectionStateChanged(Server*, Konversation::ConnectionState)),
-                TQT_SLOT(connectionStateChanged(Server*, Konversation::ConnectionState)));
+        connect(server, TQ_SIGNAL(connectionStateChanged(Server*, Konversation::ConnectionState)),
+                TQ_SLOT(connectionStateChanged(Server*, Konversation::ConnectionState)));
     ChatWindow::setServer(server);
     if (!server->getKeyForRecipient(getName()).isNull())
         blowfishLabel->show();
@@ -1268,7 +1268,7 @@ void Channel::joinNickname(ChannelNickPtr channelNick)
         appendCommandMessage(i18n("Join"),i18n("%1 is the channel and %2 is our hostmask",
                              "You have joined the channel %1 (%2).").arg(getName()).arg(channelNick->getHostmask()),false, false, true);
         m_ownChannelNick = channelNick;
-        connect(m_ownChannelNick, TQT_SIGNAL(channelNickChanged()), TQT_SLOT(refreshModeButtons()));
+        connect(m_ownChannelNick, TQ_SIGNAL(channelNickChanged()), TQ_SLOT(refreshModeButtons()));
         refreshModeButtons();
         setActive(true);
 
@@ -2101,7 +2101,7 @@ void Channel::updateQuickButtons(const TQStringList &newButtonList)
         QuickButton* quickButton = new QuickButton(TQString(), TQString(), buttonsGrid);
         buttonList.append(quickButton);
 
-        connect(quickButton, TQT_SIGNAL(clicked(const TQString &)), this, TQT_SLOT(quickButtonClicked(const TQString &)));
+        connect(quickButton, TQ_SIGNAL(clicked(const TQString &)), this, TQ_SLOT(quickButtonClicked(const TQString &)));
 
         // Get the button definition
         TQString buttonText=newButtonList[index];
@@ -2353,7 +2353,7 @@ void Channel::addPendingNickList(const TQStringList& pendingChannelNickList)
     if (!m_processingTimer)
     {
         m_processingTimer = new TQTimer(this);
-        connect(m_processingTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(processPendingNicks()));
+        connect(m_processingTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(processPendingNicks()));
     }
 
     m_pendingChannelNickLists.append(pendingChannelNickList);
@@ -2702,7 +2702,7 @@ void Channel::requestNickListSort()
     if(!m_delayedSortTimer)
     {
         m_delayedSortTimer = new TQTimer(this);
-        connect(m_delayedSortTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(sortNickList()));
+        connect(m_delayedSortTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(sortNickList()));
     }
 
     if(!m_delayedSortTimer->isActive())
