@@ -22,12 +22,12 @@
 #include <tqheader.h>
 #include <tqtoolbutton.h>
 
-#include <klocale.h>
-#include <klistview.h>
+#include <tdelocale.h>
+#include <tdelistview.h>
 #include <ktextedit.h>
 #include <klineedit.h>
 #include <knuminput.h>
-#include <klistviewsearchline.h>
+#include <tdelistviewsearchline.h>
 #include <kiconloader.h>
 
 
@@ -58,28 +58,28 @@ namespace Konversation
         m_channel = channel;
         m_editingTopic = false;
 
-        connect(m_widget->topicHistoryList, TQT_SIGNAL(clicked(TQListViewItem*)), this, TQT_SLOT(topicHistoryItemClicked(TQListViewItem*)));
-        connect(m_widget->topicHistoryList, TQT_SIGNAL(selectionChanged(TQListViewItem*)), this, TQT_SLOT(topicHistoryItemClicked(TQListViewItem*)));
-        connect(m_widget->toggleAdvancedModes, TQT_SIGNAL(clicked()), this, TQT_SLOT(toggleAdvancedModes()));
-        connect(m_widget->topicEdit, TQT_SIGNAL(modificationChanged(bool)), this, TQT_SLOT(topicBeingEdited(bool)));
+        connect(m_widget->topicHistoryList, TQ_SIGNAL(clicked(TQListViewItem*)), this, TQ_SLOT(topicHistoryItemClicked(TQListViewItem*)));
+        connect(m_widget->topicHistoryList, TQ_SIGNAL(selectionChanged(TQListViewItem*)), this, TQ_SLOT(topicHistoryItemClicked(TQListViewItem*)));
+        connect(m_widget->toggleAdvancedModes, TQ_SIGNAL(clicked()), this, TQ_SLOT(toggleAdvancedModes()));
+        connect(m_widget->topicEdit, TQ_SIGNAL(modificationChanged(bool)), this, TQ_SLOT(topicBeingEdited(bool)));
 
-        connect(m_channel, TQT_SIGNAL(topicHistoryChanged()), this, TQT_SLOT(refreshTopicHistory()));
+        connect(m_channel, TQ_SIGNAL(topicHistoryChanged()), this, TQ_SLOT(refreshTopicHistory()));
 
-        connect(m_channel, TQT_SIGNAL(modesChanged()), this, TQT_SLOT(refreshModes()));
-        connect(m_channel->getOwnChannelNick(), TQT_SIGNAL(channelNickChanged()), this, TQT_SLOT(refreshEnableModes()));
+        connect(m_channel, TQ_SIGNAL(modesChanged()), this, TQ_SLOT(refreshModes()));
+        connect(m_channel->getOwnChannelNick(), TQ_SIGNAL(channelNickChanged()), this, TQ_SLOT(refreshEnableModes()));
 
-        connect(this, TQT_SIGNAL(cancelClicked()), this, TQT_SLOT(cancelClicked()));
-        connect(this, TQT_SIGNAL(okClicked()), this, TQT_SLOT(changeOptions()));
-        connect(this, TQT_SIGNAL(okClicked()), this, TQT_SLOT(okClicked()));
+        connect(this, TQ_SIGNAL(cancelClicked()), this, TQ_SLOT(cancelClicked()));
+        connect(this, TQ_SIGNAL(okClicked()), this, TQ_SLOT(changeOptions()));
+        connect(this, TQ_SIGNAL(okClicked()), this, TQ_SLOT(okClicked()));
 
-        connect(m_channel, TQT_SIGNAL(banAdded(const TQString&)), this, TQT_SLOT(addBan(const TQString&)));
-        connect(m_channel, TQT_SIGNAL(banRemoved(const TQString&)), this, TQT_SLOT(removeBan(const TQString&)));
-        connect(m_channel, TQT_SIGNAL(banListCleared()), m_widget->banList, TQT_SLOT(clear()));
+        connect(m_channel, TQ_SIGNAL(banAdded(const TQString&)), this, TQ_SLOT(addBan(const TQString&)));
+        connect(m_channel, TQ_SIGNAL(banRemoved(const TQString&)), this, TQ_SLOT(removeBan(const TQString&)));
+        connect(m_channel, TQ_SIGNAL(banListCleared()), m_widget->banList, TQ_SLOT(clear()));
 
-        connect(m_widget->addBan, TQT_SIGNAL(clicked()), this, TQT_SLOT(addBanClicked()));
-        connect(m_widget->removeBan, TQT_SIGNAL(clicked()), this, TQT_SLOT(removeBanClicked()));
-        connect(m_widget->banList, TQT_SIGNAL(itemRenamed (TQListViewItem*)), this, TQT_SLOT(banEdited(TQListViewItem*)));
-        connect(m_widget->banList, TQT_SIGNAL(itemRenamed (TQListViewItem*, int, const TQString&)), this, TQT_SLOT(banEdited(TQListViewItem*)));
+        connect(m_widget->addBan, TQ_SIGNAL(clicked()), this, TQ_SLOT(addBanClicked()));
+        connect(m_widget->removeBan, TQ_SIGNAL(clicked()), this, TQ_SLOT(removeBanClicked()));
+        connect(m_widget->banList, TQ_SIGNAL(itemRenamed (TQListViewItem*)), this, TQ_SLOT(banEdited(TQListViewItem*)));
+        connect(m_widget->banList, TQ_SIGNAL(itemRenamed (TQListViewItem*, int, const TQString&)), this, TQ_SLOT(banEdited(TQListViewItem*)));
 
         refreshTopicHistory();
         refreshBanList();
@@ -172,7 +172,7 @@ namespace Konversation
         {
             TQDateTime date;
             date.setTime_t((*it).section(' ', 0 ,0).toUInt());
-            new KListViewItem(m_widget->topicHistoryList, (*it).section(' ', 1, 1), date.toString(Qt::LocalDate), (*it).section(' ', 2));
+            new TDEListViewItem(m_widget->topicHistoryList, (*it).section(' ', 1, 1), date.toString(TQt::LocalDate), (*it).section(' ', 2));
         }
 
         // update topic preview
@@ -446,9 +446,9 @@ namespace Konversation
     {
         if (m_widget->banList->renameLineEdit()->isShown())
         {
-            TQKeyEvent e(TQEvent::KeyPress, TQt::Key_Escape, 27, Qt::NoButton);
+            TQKeyEvent e(TQEvent::KeyPress, TQt::Key_Escape, 27, TQt::NoButton);
 
-            KApplication::sendEvent(m_widget->banList->renameLineEdit(), &e);
+            TDEApplication::sendEvent(m_widget->banList->renameLineEdit(), &e);
         }
 
         topicBeingEdited(false);
@@ -459,35 +459,35 @@ namespace Konversation
     {
         if (m_widget->banList->renameLineEdit()->isShown())
         {
-            TQKeyEvent e(TQEvent::KeyPress, TQt::Key_Return, 13, Qt::NoButton);
+            TQKeyEvent e(TQEvent::KeyPress, TQt::Key_Return, 13, TQt::NoButton);
 
-            KApplication::sendEvent(m_widget->banList->renameLineEdit(), &e);
+            TDEApplication::sendEvent(m_widget->banList->renameLineEdit(), &e);
         }
     }
 
     // This is our implementation of BanListViewItem
 
     BanListViewItem::BanListViewItem(TQListView *parent)
-      : KListViewItem(parent)
+      : TDEListViewItem(parent)
     {
         m_isNewBan = 0;
     }
 
     BanListViewItem::BanListViewItem(TQListView *parent, bool isNew)
-      : KListViewItem(parent)
+      : TDEListViewItem(parent)
     {
         m_isNewBan = isNew;
     }
 
     BanListViewItem::BanListViewItem (TQListView *parent, const TQString& label1, const TQString& label2,
-        uint timestamp) : KListViewItem(parent, label1, label2)
+        uint timestamp) : TDEListViewItem(parent, label1, label2)
     {
         m_isNewBan = 0;
         m_timestamp.setTime_t(timestamp);
     }
 
     BanListViewItem::BanListViewItem (TQListView *parent, bool isNew, const TQString& label1, const TQString& label2,
-        uint timestamp) : KListViewItem(parent, label1, label2)
+        uint timestamp) : TDEListViewItem(parent, label1, label2)
     {
         m_isNewBan = isNew;
         m_timestamp.setTime_t(timestamp);
@@ -496,9 +496,9 @@ namespace Konversation
     TQString BanListViewItem::text(int column) const
     {
         if (column == 2)
-            return KGlobal::locale()->formatDateTime(m_timestamp, true, true);
+            return TDEGlobal::locale()->formatDateTime(m_timestamp, true, true);
 
-        return KListViewItem::text(column);
+        return TDEListViewItem::text(column);
     }
 
     int BanListViewItem::compare(TQListViewItem *i, int col, bool ascending) const
@@ -515,14 +515,14 @@ namespace Konversation
                 return 1;
         }
 
-        return KListViewItem::compare(i, col, ascending);
+        return TDEListViewItem::compare(i, col, ascending);
     }
 
     void BanListViewItem::startRename( int col )
     {
         m_oldValue = text(col);
 
-        KListViewItem::startRename(col);
+        TDEListViewItem::startRename(col);
     }
 
     void BanListViewItem::cancelRename( int col )
@@ -530,7 +530,7 @@ namespace Konversation
         if (text(col).isEmpty() && m_isNewBan)
             delete this;
         else
-            KListViewItem::cancelRename(col);
+            TDEListViewItem::cancelRename(col);
     }
 }
 
