@@ -71,8 +71,9 @@ Preferences::Preferences()
     Konversation::ServerGroupSettingsPtr serverGroup = new Konversation::ServerGroupSettings;
     serverGroup->setName("Trinity IRC");
     Konversation::ServerSettings server;
-    server.setHost("irc.freenode.net");
-    server.setPort(8001);
+    server.setHost("irc.libera.chat");
+    server.setPort(6697);
+    server.setSSLEnabled(true);
     serverGroup->addServer(server);
     serverGroup->setIdentityId(mIdentity->id());
     Konversation::ChannelSettings channel;
