@@ -25,7 +25,7 @@
 
 ConnectionManager::ConnectionManager(TQObject* parent) : TQObject(parent)
 {
-    connect(this, TQT_SIGNAL(requestReconnect(Server*)), this, TQT_SLOT(handleReconnect(Server*)));
+    connect(this, TQ_SIGNAL(requestReconnect(Server*)), this, TQ_SLOT(handleReconnect(Server*)));
 }
 
 ConnectionManager::~ConnectionManager()
@@ -109,22 +109,22 @@ void ConnectionManager::connectTo(Konversation::ConnectionFlag flag, ConnectionS
 
     enlistConnection(server->connectionId(), server);
 
-    connect(server, TQT_SIGNAL(destroyed(int)), this, TQT_SLOT(delistConnection(int)));
+    connect(server, TQ_SIGNAL(destroyed(int)), this, TQ_SLOT(delistConnection(int)));
 
-    connect(server, TQT_SIGNAL(connectionStateChanged(Server*, Konversation::ConnectionState)),
-            this, TQT_SLOT(handleConnectionStateChange(Server*, Konversation::ConnectionState)));
+    connect(server, TQ_SIGNAL(connectionStateChanged(Server*, Konversation::ConnectionState)),
+            this, TQ_SLOT(handleConnectionStateChange(Server*, Konversation::ConnectionState)));
 
-    connect(server, TQT_SIGNAL(awayState(bool)), this, TQT_SIGNAL(connectionChangedAwayState(bool)));
+    connect(server, TQ_SIGNAL(awayState(bool)), this, TQ_SIGNAL(connectionChangedAwayState(bool)));
 
-    connect(server, TQT_SIGNAL(nicksNowOnline(Server*, const TQStringList&, bool)),
-        mainWindow, TQT_SLOT(setOnlineList(Server*, const TQStringList&,bool)));
-    connect(server, TQT_SIGNAL(awayInsertRememberLine(Server*)),
-        mainWindow, TQT_SIGNAL(triggerRememberLines(Server*)));
+    connect(server, TQ_SIGNAL(nicksNowOnline(Server*, const TQStringList&, bool)),
+        mainWindow, TQ_SLOT(setOnlineList(Server*, const TQStringList&,bool)));
+    connect(server, TQ_SIGNAL(awayInsertRememberLine(Server*)),
+        mainWindow, TQ_SIGNAL(triggerRememberLines(Server*)));
 
-    connect(mainWindow, TQT_SIGNAL(startNotifyTimer(int)), server, TQT_SLOT(startNotifyTimer(int)));
+    connect(mainWindow, TQ_SIGNAL(startNotifyTimer(int)), server, TQ_SLOT(startNotifyTimer(int)));
 
-    connect(server, TQT_SIGNAL(multiServerCommand(const TQString&, const TQString&)),
-        konvApp, TQT_SLOT(sendMultiServerCommand(const TQString&, const TQString&)));
+    connect(server, TQ_SIGNAL(multiServerCommand(const TQString&, const TQString&)),
+        konvApp, TQ_SLOT(sendMultiServerCommand(const TQString&, const TQString&)));
 }
 
 void ConnectionManager::enlistConnection(int connectionId, Server* server)
@@ -215,7 +215,7 @@ void ConnectionManager::handleReconnect(Server* server)
 
         server->getConnectionSettings().incrementReconnectCount();
 
-        TQTimer::singleShot(Preferences::reconnectDelay() * 1000, server, TQT_SLOT(connectToIRCServer()));
+        TQTimer::singleShot(Preferences::reconnectDelay() * 1000, server, TQ_SLOT(connectToIRCServer()));
     }
     else
         server->getStatusView()->appendServerMessage(i18n("Error"), i18n("Reconnection attempts exceeded."));
