@@ -22,7 +22,7 @@ class ConnectionSettings;
 
 class ConnectionManager : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
