@@ -35,7 +35,7 @@ namespace Konversation
 
 class DccChat : public ChatWindow
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
         public:
