@@ -73,7 +73,7 @@ DccResumeDialog::DccResumeDialog(DccTransferRecv* item, const TQString& caption,
     labelMessage->setText(message);
 
     m_urlreqFileURL = new KURLRequester(m_item->getFileURL().prettyURL(), page);
-    connect(m_urlreqFileURL, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(updateDialogButtons()));
+    connect(m_urlreqFileURL, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(updateDialogButtons()));
 
     pageLayout->addWidget(labelMessage);
     pageLayout->addWidget(m_urlreqFileURL);
@@ -89,8 +89,8 @@ DccResumeDialog::DccResumeDialog(DccTransferRecv* item, const TQString& caption,
         filePathToolsLayout->addItem(new TQSpacerItem(0, 0, TQSizePolicy::Expanding));
         filePathToolsLayout->addWidget(btnDefaultName);
         filePathToolsLayout->addWidget(btnSuggestNewName);
-        connect(btnSuggestNewName, TQT_SIGNAL(clicked()), this, TQT_SLOT(suggestNewName()));
-        connect(btnDefaultName, TQT_SIGNAL(clicked()), this, TQT_SLOT(setDefaultName()));
+        connect(btnSuggestNewName, TQ_SIGNAL(clicked()), this, TQ_SLOT(suggestNewName()));
+        connect(btnDefaultName, TQ_SIGNAL(clicked()), this, TQ_SLOT(setDefaultName()));
 
         pageLayout->addWidget(filePathToolsFrame);
 
