@@ -21,7 +21,7 @@ class DccTransferRecv;
 
 class DccResumeDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
         public:
