@@ -29,7 +29,7 @@ typedef double transferspeed_t;
 
 class DccTransfer : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
