@@ -46,7 +46,7 @@ DccTransferPanel::DccTransferPanel(TQWidget* parent) : ChatWindow(parent)
 
     initGUI();
 
-    connect( KonversationApplication::instance()->getDccTransferManager(), TQT_SIGNAL( newTransferAdded( DccTransfer* ) ), this, TQT_SLOT( slotNewTransferAdded( DccTransfer* ) ) );
+    connect( KonversationApplication::instance()->getDccTransferManager(), TQ_SIGNAL( newTransferAdded( DccTransfer* ) ), this, TQ_SLOT( slotNewTransferAdded( DccTransfer* ) ) );
 }
 
 DccTransferPanel::~DccTransferPanel()
@@ -98,7 +98,7 @@ void DccTransferPanel::initGUI()
 
     m_listView->setSorting(Column::OfferDate, false);
 
-    connect(m_listView,TQT_SIGNAL (selectionChanged()),this,TQT_SLOT (updateButton()) );
+    connect(m_listView,TQ_SIGNAL (selectionChanged()),this,TQ_SLOT (updateButton()) );
 
     // detailed info panel
     m_detailPanel = new DccTransferDetailedInfoPanel(this);
@@ -123,12 +123,12 @@ void DccTransferPanel::initGUI()
     TQToolTip::add( m_buttonOpen,   i18n( "Run the file" ) );
     TQToolTip::add( m_buttonDetail, i18n( "View DCC transfer details" ) );
 
-    connect( m_buttonAccept, TQT_SIGNAL(clicked()), this, TQT_SLOT(acceptDcc()) );
-    connect( m_buttonAbort,  TQT_SIGNAL(clicked()), this, TQT_SLOT(abortDcc()) );
-    connect( m_buttonClear,  TQT_SIGNAL(clicked()), this, TQT_SLOT(clearDcc()) );
-    connect( m_buttonOpen,   TQT_SIGNAL(clicked()), this, TQT_SLOT(runDcc()) );
-    //connect( m_buttonDetail, TQT_SIGNAL(clicked()), this, TQT_SLOT(openDetail()) );
-    connect( m_buttonDetail, TQT_SIGNAL(toggled(bool)), m_detailPanel, TQT_SLOT(setShown(bool)) );
+    connect( m_buttonAccept, TQ_SIGNAL(clicked()), this, TQ_SLOT(acceptDcc()) );
+    connect( m_buttonAbort,  TQ_SIGNAL(clicked()), this, TQ_SLOT(abortDcc()) );
+    connect( m_buttonClear,  TQ_SIGNAL(clicked()), this, TQ_SLOT(clearDcc()) );
+    connect( m_buttonOpen,   TQ_SIGNAL(clicked()), this, TQ_SLOT(runDcc()) );
+    //connect( m_buttonDetail, TQ_SIGNAL(clicked()), this, TQ_SLOT(openDetail()) );
+    connect( m_buttonDetail, TQ_SIGNAL(toggled(bool)), m_detailPanel, TQ_SLOT(setShown(bool)) );
     m_buttonDetail->setOn(true);
 
 
@@ -150,13 +150,13 @@ void DccTransferPanel::initGUI()
 
     #undef icon
 
-    connect(m_listView, TQT_SIGNAL(contextMenuRequested(TQListViewItem*,const TQPoint&,int)), this, TQT_SLOT(popupRequested(TQListViewItem*,const TQPoint&,int)));
-    connect(m_popup, TQT_SIGNAL(activated(int)), this, TQT_SLOT(popupActivated(int)));
+    connect(m_listView, TQ_SIGNAL(contextMenuRequested(TQListViewItem*,const TQPoint&,int)), this, TQ_SLOT(popupRequested(TQListViewItem*,const TQPoint&,int)));
+    connect(m_popup, TQ_SIGNAL(activated(int)), this, TQ_SLOT(popupActivated(int)));
 
     // misc.
-    connect(m_listView, TQT_SIGNAL(doubleClicked(TQListViewItem*,const TQPoint&,int)), this, TQT_SLOT(doubleClicked(TQListViewItem*,const TQPoint&,int)));
+    connect(m_listView, TQ_SIGNAL(doubleClicked(TQListViewItem*,const TQPoint&,int)), this, TQ_SLOT(doubleClicked(TQListViewItem*,const TQPoint&,int)));
 
-    connect(m_listView, TQT_SIGNAL(currentChanged(TQListViewItem*)), this, TQT_SLOT(setDetailPanelItem(TQListViewItem*)));
+    connect(m_listView, TQ_SIGNAL(currentChanged(TQListViewItem*)), this, TQ_SLOT(setDetailPanelItem(TQListViewItem*)));
 
     updateButton();
 }
@@ -164,7 +164,7 @@ void DccTransferPanel::initGUI()
 void DccTransferPanel::slotNewTransferAdded( DccTransfer* transfer )
 {
     DccTransferPanelItem* item = new DccTransferPanelItem( this, transfer );
-    connect( transfer, TQT_SIGNAL( statusChanged( DccTransfer*, int, int ) ), this, TQT_SLOT( slotTransferStatusChanged() ) );
+    connect( transfer, TQ_SIGNAL( statusChanged( DccTransfer*, int, int ) ), this, TQ_SLOT( slotTransferStatusChanged() ) );
     if ( m_listView->childCount() == 1 )
     {
         m_listView->clearSelection();
