@@ -45,11 +45,11 @@ DccTransferPanelItem::DccTransferPanelItem( DccTransferPanel* panel, DccTransfer
     m_progressBar->setCenterIndicator( true );
     m_progressBar->setPercentageVisible( true );
 
-    connect( m_transfer, TQT_SIGNAL( transferStarted( DccTransfer* ) ), this, TQT_SLOT( startAutoViewUpdate() ) );
-    connect( m_transfer, TQT_SIGNAL( done( DccTransfer* ) ), this, TQT_SLOT( stopAutoViewUpdate() ) );
-    connect( m_transfer, TQT_SIGNAL( done( DccTransfer* ) ), this, TQT_SLOT( backupTransferInfo( DccTransfer* ) ) );
+    connect( m_transfer, TQ_SIGNAL( transferStarted( DccTransfer* ) ), this, TQ_SLOT( startAutoViewUpdate() ) );
+    connect( m_transfer, TQ_SIGNAL( done( DccTransfer* ) ), this, TQ_SLOT( stopAutoViewUpdate() ) );
+    connect( m_transfer, TQ_SIGNAL( done( DccTransfer* ) ), this, TQ_SLOT( backupTransferInfo( DccTransfer* ) ) );
 
-    connect( m_transfer, TQT_SIGNAL( statusChanged( DccTransfer*, int, int ) ), this, TQT_SLOT( slotStatusChanged( DccTransfer*, int, int ) ) );
+    connect( m_transfer, TQ_SIGNAL( statusChanged( DccTransfer*, int, int ) ), this, TQ_SLOT( slotStatusChanged( DccTransfer*, int, int ) ) );
 
     updateView();
 }
@@ -141,7 +141,7 @@ void DccTransferPanelItem::startAutoViewUpdate()
 {
     stopAutoViewUpdate();
     m_autoUpdateViewTimer = new TQTimer( this );
-    connect( m_autoUpdateViewTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( updateView()) );
+    connect( m_autoUpdateViewTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( updateView()) );
     m_autoUpdateViewTimer->start( 500 );
 }
 
