@@ -67,7 +67,7 @@ DccTransferRecv::DccTransferRecv(TQObject* parent)
     m_writeCacheHandler = 0;
 
     m_connectionTimer = new TQTimer( this );
-    connect( m_connectionTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( connectionTimeout() ) );
+    connect( m_connectionTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( connectionTimeout() ) );
     //timer hasn't started yet.  qtimer will be deleted automatically when 'this' object is deleted
 }
 
@@ -285,9 +285,9 @@ void DccTransferRecv::prepareLocalKio( bool overwrite, bool resume, TDEIO::fileo
         return;
     }
 
-    connect( transferJob, TQT_SIGNAL( canResume( TDEIO::Job*, TDEIO::filesize_t ) ), this, TQT_SLOT( slotLocalCanResume( TDEIO::Job*, TDEIO::filesize_t ) ) );
-    connect( transferJob, TQT_SIGNAL( result( TDEIO::Job* ) ),                     this, TQT_SLOT( slotLocalGotResult( TDEIO::Job* ) ) );
-    connect( transferJob, TQT_SIGNAL( dataReq( TDEIO::Job*, TQByteArray& ) ),       this, TQT_SLOT( slotLocalReady( TDEIO::Job* ) ) );
+    connect( transferJob, TQ_SIGNAL( canResume( TDEIO::Job*, TDEIO::filesize_t ) ), this, TQ_SLOT( slotLocalCanResume( TDEIO::Job*, TDEIO::filesize_t ) ) );
+    connect( transferJob, TQ_SIGNAL( result( TDEIO::Job* ) ),                     this, TQ_SLOT( slotLocalGotResult( TDEIO::Job* ) ) );
+    connect( transferJob, TQ_SIGNAL( dataReq( TDEIO::Job*, TQByteArray& ) ),       this, TQ_SLOT( slotLocalReady( TDEIO::Job* ) ) );
 }
 
 void DccTransferRecv::askAndPrepareLocalKio( const TQString& message, int enabledActions, DccResumeDialog::ReceiveAction defaultAction, TDEIO::fileoffset_t startPosition )
@@ -419,8 +419,8 @@ void DccTransferRecv::slotLocalReady( TDEIO::Job* job )
 
     m_writeCacheHandler = new DccTransferRecvWriteCacheHandler( transferJob );
 
-    connect( m_writeCacheHandler, TQT_SIGNAL( done() ),                     this, TQT_SLOT( slotLocalWriteDone() )                     );
-    connect( m_writeCacheHandler, TQT_SIGNAL( gotError( const TQString& ) ), this, TQT_SLOT( slotLocalGotWriteError( const TQString& ) ) );
+    connect( m_writeCacheHandler, TQ_SIGNAL( done() ),                     this, TQ_SLOT( slotLocalWriteDone() )                     );
+    connect( m_writeCacheHandler, TQ_SIGNAL( gotError( const TQString& ) ), this, TQ_SLOT( slotLocalGotWriteError( const TQString& ) ) );
 
     if ( !m_resumed )
         connectWithSender();
@@ -515,8 +515,8 @@ void DccTransferRecv::connectToSendServer()
     m_recvSocket->enableRead( false );
     m_recvSocket->enableWrite( false );
 
-    connect( m_recvSocket, TQT_SIGNAL( connected( const KResolverEntry& ) ), this, TQT_SLOT( startReceiving() )     );
-    connect( m_recvSocket, TQT_SIGNAL( gotError( int ) ),                    this, TQT_SLOT( connectionFailed( int ) ) );
+    connect( m_recvSocket, TQ_SIGNAL( connected( const KResolverEntry& ) ), this, TQ_SLOT( startReceiving() )     );
+    connect( m_recvSocket, TQ_SIGNAL( gotError( int ) ),                    this, TQ_SLOT( connectionFailed( int ) ) );
 
     kdDebug() << "DccTransferRecv::connectToServer(): attempting to connect to " << m_partnerIp << ":" << m_partnerPort << endl;
 
@@ -537,8 +537,8 @@ bool DccTransferRecv::startListeningForSender()
         return false;
     }
 
-   connect( m_serverSocket, TQT_SIGNAL( readyAccept() ),   this, TQT_SLOT( slotServerSocketReadyAccept() ) );
-   connect( m_serverSocket, TQT_SIGNAL( gotError( int ) ), this, TQT_SLOT( slotServerSocketGotError( int ) ) );
+   connect( m_serverSocket, TQ_SIGNAL( readyAccept() ),   this, TQ_SLOT( slotServerSocketReadyAccept() ) );
+   connect( m_serverSocket, TQ_SIGNAL( gotError( int ) ), this, TQ_SLOT( slotServerSocketGotError( int ) ) );
 
     return true;
 }
@@ -554,7 +554,7 @@ void DccTransferRecv::slotServerSocketReadyAccept()
         return;
     }
 
-    connect( m_recvSocket, TQT_SIGNAL( gotError( int ) ), this, TQT_SLOT( connectionFailed( int ) ) );
+    connect( m_recvSocket, TQ_SIGNAL( gotError( int ) ), this, TQ_SLOT( connectionFailed( int ) ) );
 
     // we don't need ServerSocket anymore
     m_serverSocket->close();
@@ -573,9 +573,9 @@ void DccTransferRecv::startReceiving()
 
     m_recvSocket->setBlocking( false );           // asynchronous mode
 
-    connect( m_recvSocket, TQT_SIGNAL( readyRead() ),                        this, TQT_SLOT( readData() )              );
-    connect( m_recvSocket, TQT_SIGNAL( readyWrite() ),                       this, TQT_SLOT( sendAck() )               );
-    connect( m_recvSocket, TQT_SIGNAL( closed() ),                           this, TQT_SLOT( slotSocketClosed() )      );
+    connect( m_recvSocket, TQ_SIGNAL( readyRead() ),                        this, TQ_SLOT( readData() )              );
+    connect( m_recvSocket, TQ_SIGNAL( readyWrite() ),                       this, TQ_SLOT( sendAck() )               );
+    connect( m_recvSocket, TQ_SIGNAL( closed() ),                           this, TQ_SLOT( slotSocketClosed() )      );
 
     setStatus( Transferring );
 
@@ -682,9 +682,9 @@ DccTransferRecvWriteCacheHandler::DccTransferRecvWriteCacheHandler( TDEIO::Trans
     m_writeReady = true;
     m_cacheStream = 0;
 
-    connect( this,          TQT_SIGNAL( dataFinished() ),                    m_transferJob, TQT_SLOT( slotFinished() )                           );
-    connect( m_transferJob, TQT_SIGNAL( dataReq( TDEIO::Job*, TQByteArray& ) ), this,          TQT_SLOT( slotKIODataReq( TDEIO::Job*, TQByteArray& ) ) );
-    connect( m_transferJob, TQT_SIGNAL( result( TDEIO::Job* ) ),               this,          TQT_SLOT( slotKIOResult( TDEIO::Job* ) )               );
+    connect( this,          TQ_SIGNAL( dataFinished() ),                    m_transferJob, TQ_SLOT( slotFinished() )                           );
+    connect( m_transferJob, TQ_SIGNAL( dataReq( TDEIO::Job*, TQByteArray& ) ), this,          TQ_SLOT( slotKIODataReq( TDEIO::Job*, TQByteArray& ) ) );
+    connect( m_transferJob, TQ_SIGNAL( result( TDEIO::Job* ) ),               this,          TQ_SLOT( slotKIOResult( TDEIO::Job* ) )               );
 
     m_transferJob->setAsyncDataEnabled( m_writeAsyncMode = true );
 }
