@@ -32,7 +32,7 @@ namespace KNetwork
 
 class DccTransferSend : public DccTransfer
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
         public:
