@@ -22,7 +22,7 @@
 class Ignore;
 class Ignore_Config : public Ignore_ConfigUI, public KonviSettingsPage
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
