@@ -16,10 +16,10 @@
 
 #include <tqstring.h>
 
-#include <klistview.h>
+#include <tdelistview.h>
 
 
-class IgnoreListViewItem : public KListViewItem
+class IgnoreListViewItem : public TDEListViewItem
 {
     public:
         IgnoreListViewItem(TQListView* parent,const TQString& name,int flags);
