@@ -25,7 +25,7 @@ class TQMouseEvent;
 
 class IRCInput : public KTextEdit
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
