@@ -33,15 +33,15 @@ IRCViewBox::IRCViewBox(TQWidget* parent, Server* newServer)
     m_searchBar->hide();
     m_matchedOnce = false;
 
-    connect(m_searchBar, TQT_SIGNAL(signalSearchChanged(const TQString&)),
-        this, TQT_SLOT(slotSearchChanged(const TQString&)));
-    connect(m_searchBar, TQT_SIGNAL(signalSearchNext()),
-        this, TQT_SLOT(slotSearchNext()));
-    connect(m_searchBar, TQT_SIGNAL(signalSearchPrevious()),
-            this, TQT_SLOT(slotSearchPrevious()));
-    connect(m_ircView, TQT_SIGNAL(doSearch()),
-        TQT_SLOT(slotSearch()));
-    connect(m_searchBar, TQT_SIGNAL(hidden()), m_ircView, TQT_SIGNAL(gotFocus()));
+    connect(m_searchBar, TQ_SIGNAL(signalSearchChanged(const TQString&)),
+        this, TQ_SLOT(slotSearchChanged(const TQString&)));
+    connect(m_searchBar, TQ_SIGNAL(signalSearchNext()),
+        this, TQ_SLOT(slotSearchNext()));
+    connect(m_searchBar, TQ_SIGNAL(signalSearchPrevious()),
+            this, TQ_SLOT(slotSearchPrevious()));
+    connect(m_ircView, TQ_SIGNAL(doSearch()),
+        TQ_SLOT(slotSearch()));
+    connect(m_searchBar, TQ_SIGNAL(hidden()), m_ircView, TQ_SIGNAL(gotFocus()));
 }
 
 IRCViewBox::~IRCViewBox()
