@@ -50,7 +50,7 @@ m_mainWindow(mainWindow)
     manager->setUpdate( true );
     manager->setShowNSBookmarks( false );
 
-    connect( manager, TQT_SIGNAL(changed(const TQString &,const TQString &)), TQT_SLOT(slotBookmarksChanged(const TQString &,const TQString &)));
+    connect( manager, TQ_SIGNAL(changed(const TQString &,const TQString &)), TQ_SLOT(slotBookmarksChanged(const TQString &,const TQString &)));
 
     m_bookmarkMenu = new KonviBookmarkMenu( manager, this, m_menu, NULL, true );
 }
