@@ -50,7 +50,7 @@ class TDEConfigDialogManager;
 
 class KonviConfigDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     signals:
