@@ -32,7 +32,7 @@ namespace Konversation
 {
     class Addressbook : public AddressbookBase
     {
-        Q_OBJECT
+        TQ_OBJECT
   
             public:
 
