@@ -20,19 +20,19 @@
 
 #include <tqstringlist.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstringhandler.h>
 #include <krun.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <dcopclient.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 namespace Konversation
 {
 
     AddressbookBase::AddressbookBase()
     {
-        KABC::StdAddressBook::setAutomaticSave( false );
+        TDEABC::StdAddressBook::setAutomaticSave( false );
         m_ticket=NULL;
     }
 
@@ -40,32 +40,32 @@ namespace Konversation
     {
     }
 
-    KABC::AddressBook *AddressbookBase::getAddressBook() { return addressBook; }
+    TDEABC::AddressBook *AddressbookBase::getAddressBook() { return addressBook; }
 
-    KABC::Addressee AddressbookBase::getKABCAddresseeFromNick(const TQString &ircnick, const TQString &servername, const TQString &servergroup)
+    TDEABC::Addressee AddressbookBase::getKABCAddresseeFromNick(const TQString &ircnick, const TQString &servername, const TQString &servergroup)
     {
-        KABC::AddressBook::Iterator it;
+        TDEABC::AddressBook::Iterator it;
 
         for( it = addressBook->begin(); it != addressBook->end(); ++it )
         {
             if(hasNick(*it, ircnick, servername, servergroup))
                 return (*it);
         }
-        return KABC::Addressee();
+        return TDEABC::Addressee();
     }
-    KABC::Addressee AddressbookBase::getKABCAddresseeFromNick(const TQString &nick_server)
+    TDEABC::Addressee AddressbookBase::getKABCAddresseeFromNick(const TQString &nick_server)
     {
-        KABC::AddressBook::Iterator it;
+        TDEABC::AddressBook::Iterator it;
 
         for( it = addressBook->begin(); it != addressBook->end(); ++it )
         {
             if(hasNick(*it, nick_server))
                 return (*it);
         }
-        return KABC::Addressee();
+        return TDEABC::Addressee();
     }
 
-    bool AddressbookBase::hasNick(const KABC::Addressee &addressee, const TQString &ircnick, const TQString &servername, const TQString &servergroup)
+    bool AddressbookBase::hasNick(const TDEABC::Addressee &addressee, const TQString &ircnick, const TQString &servername, const TQString &servergroup)
     {
 
         TQString lnick = ircnick.lower();
@@ -92,13 +92,13 @@ namespace Konversation
     TQStringList AddressbookBase::allContactsNicksForServer(const TQString &servername, const TQString &servergroup)
     {
         TQStringList contacts;
-        for( KABC::AddressBook::Iterator it = addressBook->begin(); it != addressBook->end(); ++it )
+        for( TDEABC::AddressBook::Iterator it = addressBook->begin(); it != addressBook->end(); ++it )
             contacts += getNicks(*it, servername, servergroup);
         return contacts;
 
     }
 
-    TQStringList AddressbookBase::getNicks(const KABC::Addressee &addressee, const TQString &servername, const TQString &servergroup)
+    TQStringList AddressbookBase::getNicks(const TDEABC::Addressee &addressee, const TQString &servername, const TQString &servergroup)
     {
         TQStringList nicks;
 
@@ -121,7 +121,7 @@ namespace Konversation
         return nicks;
     }
 
-    bool AddressbookBase::hasNick(const KABC::Addressee &addressee, const TQString &nick_server)
+    bool AddressbookBase::hasNick(const TDEABC::Addressee &addressee, const TQString &nick_server)
     {
         TQString lnick_server = nick_server.lower();
         TQStringList addresses = TQStringList::split( TQChar( 0xE000 ), addressee.custom("messaging/irc", "All") );
@@ -136,7 +136,7 @@ namespace Konversation
 
     }
 
-    TQString AddressbookBase::getBestNick(const KABC::Addressee &addressee)
+    TQString AddressbookBase::getBestNick(const TDEABC::Addressee &addressee)
     {
         //Look for a nickinfo for this nick, and use that.  That way we turn a nick that is online.
         NickInfoPtr nickInfo = getNickInfo(addressee);
@@ -151,7 +151,7 @@ namespace Konversation
         return TQString();
     }
 
-    NickInfoPtr AddressbookBase::getNickInfo(const KABC::Addressee &addressee)
+    NickInfoPtr AddressbookBase::getNickInfo(const TDEABC::Addressee &addressee)
     {
         NickInfoPtr lastNickInfo;
         TQStringList addresses = TQStringList::split( TQChar( 0xE000 ), addressee.custom("messaging/irc", "All") );
@@ -175,11 +175,11 @@ namespace Konversation
         return lastNickInfo;
     }
 
-    bool AddressbookBase::hasAnyNicks(const KABC::Addressee &addressee)
+    bool AddressbookBase::hasAnyNicks(const TDEABC::Addressee &addressee)
     {
         return !addressee.custom("messaging/irc", "All").isEmpty();
     }
-    void AddressbookBase::unassociateNick(KABC::Addressee &addressee, const TQString &ircnick, const TQString &servername, const TQString &servergroup)
+    void AddressbookBase::unassociateNick(TDEABC::Addressee &addressee, const TQString &ircnick, const TQString &servername, const TQString &servergroup)
     {
 
         kdDebug() << "in unassociatenick for '" << ircnick << endl;
@@ -239,7 +239,7 @@ namespace Konversation
     }
     /**For a given contact, adds the ircnick if they don't already have it.  If you pass an addressBook, the contact is inserted
      * if it has changed. */
-    void AddressbookBase::associateNick(KABC::Addressee &addressee, const TQString &ircnick, const TQString &servername, const TQString &servergroup)
+    void AddressbookBase::associateNick(TDEABC::Addressee &addressee, const TQString &ircnick, const TQString &servername, const TQString &servergroup)
     {
         //It's easiest to just remove it from the list if it's there already
         unassociateNick(addressee, ircnick, servername, servergroup);
@@ -259,9 +259,9 @@ namespace Konversation
         addressBook->insertAddressee(addressee);
     }
     /** This function associates the nick for a person, then iterates over all the contacts unassociating the nick from everyone else. It saves the addressses that have changed.*/
-    bool AddressbookBase::associateNickAndUnassociateFromEveryoneElse(KABC::Addressee &addressee, const TQString &ircnick, const TQString &servername, const TQString &servergroup)
+    bool AddressbookBase::associateNickAndUnassociateFromEveryoneElse(TDEABC::Addressee &addressee, const TQString &ircnick, const TQString &servername, const TQString &servergroup)
     {
-        for( KABC::AddressBook::Iterator it = addressBook->begin(); it != addressBook->end(); ++it )
+        for( TDEABC::AddressBook::Iterator it = addressBook->begin(); it != addressBook->end(); ++it )
             if((*it).uid() != addressee.uid())
                 unassociateNick(*it, ircnick, servername, servergroup);
         associateNick(addressee, ircnick, servername, servergroup);
@@ -335,7 +335,7 @@ namespace Konversation
         return true;
     }
 
-    bool AddressbookBase::saveAddressee(KABC::Addressee &addressee)
+    bool AddressbookBase::saveAddressee(TDEABC::Addressee &addressee)
     {
         Q_ASSERT(&addressee);
         addressBook->insertAddressee(addressee);
@@ -354,7 +354,7 @@ namespace Konversation
      * @param addressee Addressbook contact you want to know of the presence of
      * @return 0 (unknown), 1 (offline), 3 (away), 4 (online)
      */
-    int AddressbookBase::presenceStatusByAddressee(const KABC::Addressee &addressee)
+    int AddressbookBase::presenceStatusByAddressee(const TDEABC::Addressee &addressee)
     {
         Q_ASSERT(&addressee);
         NickInfoPtr nickInfo = getNickInfo(addressee);
@@ -370,7 +370,7 @@ namespace Konversation
         return 4;
 
     }
-    bool AddressbookBase::isOnline(KABC::Addressee &addressee)
+    bool AddressbookBase::isOnline(TDEABC::Addressee &addressee)
     {
         return !!getNickInfo(addressee);
     }
@@ -384,19 +384,19 @@ namespace Konversation
         // then call it on the command line to actually put it in edit mode.  This is stupid :(
         kapp->startServiceByDesktopName( "kaddressbook" );
 
-        KProcess *proc = new KProcess;
+        TDEProcess *proc = new TDEProcess;
         *proc << "kaddressbook";
         *proc << "--editor-only" << "--uid" << uid;
         kdDebug() << "running kaddressbook --editor-only --uid " << uid << endl;
         if(!proc->start())
         {
-            KMessageBox::error(0, i18n("Could not run your addressbook program (kaddressbook).  This is most likely because it is not installed.  Please install the 'kdepim' packages."));
+            KMessageBox::error(0, i18n("Could not run your addressbook program (kaddressbook).  This is most likely because it is not installed.  Please install the 'tdepim' packages."));
             return false;
         }
         return true;
     }
 
-    bool AddressbookBase::sendEmail(const KABC::Addressee &addressee)
+    bool AddressbookBase::sendEmail(const TDEABC::Addressee &addressee)
     {
         if(addressee.preferredEmail().isEmpty())
         {
@@ -412,7 +412,7 @@ namespace Konversation
         kdDebug() << "Sending email to " << mailtoaddress << endl;
         if(proc->hasError())
         {
-            KMessageBox::error(0, i18n("Could not run your email program.  This is possibly because one is not installed.  To install the KDE email program (kmail) please install the 'kdepim' packages."));
+            KMessageBox::error(0, i18n("Could not run your email program. This is possibly because one is not installed. To install the TDE email program (kmail) please install the 'tdepim' packages."));
             return false;
         }
         return true;
@@ -430,7 +430,7 @@ namespace Konversation
         {
             NickInfoPtr nickInfo = (*it)->getNickInfo();
             Q_ASSERT(nickInfo);  if(!nickInfo) return false;
-            KABC::Addressee addr = nickInfo->getAddressee();
+            TDEABC::Addressee addr = nickInfo->getAddressee();
             if(addr.isEmpty())
             {
                 nicksWithoutAddressee.append(nickInfo->getNickname());
