@@ -20,7 +20,7 @@ class TQWheelEvent;
 
 class MultilineTextEdit : public TQTextEdit
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
