@@ -35,7 +35,7 @@ class TQTimer;
 */
 class NickInfo : public TQObject, public TDEShared
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
         public:
