@@ -29,7 +29,7 @@ class TQTimer;
 
 class NickListView : public TDEListView
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
         public:
