@@ -43,8 +43,8 @@ OSDWidget::OSDWidget( const TQString &appName, TQWidget *parent, const char *nam
     setBackgroundMode( NoBackground );
     unsetColors();
 
-    connect( &timer,     TQT_SIGNAL( timeout() ), TQT_SLOT( hide() ) );
-    connect( &timerMin,  TQT_SIGNAL( timeout() ), TQT_SLOT( minReached() ) );
+    connect( &timer,     TQ_SIGNAL( timeout() ), TQ_SLOT( hide() ) );
+    connect( &timerMin,  TQ_SIGNAL( timeout() ), TQ_SLOT( minReached() ) );
 }
 
 void OSDWidget::renderOSDText( const TQString &txt )
@@ -146,7 +146,7 @@ void OSDWidget::showOSD( const TQString &text, bool preemptive )
     }
 }
 
-void OSDWidget::minReached()                      //SLOT
+void OSDWidget::minReached()                      //TQ_SLOT
 {
     if ( !textBuffer.isEmpty() )
     {
@@ -326,7 +326,7 @@ void OSDPreviewWidget::mousePressEvent( TQMouseEvent *event )
 {
     m_dragOffset = event->pos();
 
-    if ( event->button() == Qt::LeftButton && !m_dragging )
+    if ( event->button() == TQt::LeftButton && !m_dragging )
     {
         grabMouse( KCursor::sizeAllCursor() );
         m_dragging = true;
