@@ -46,9 +46,9 @@ OSD_Config::OSD_Config( TQWidget* parent, const char* name, WFlags fl )
     kcfg_OSDScreen->setEnabled(enableScreenChooser);
 
     m_pOSDPreview = new OSDPreviewWidget("Konversation");
-    connect(m_pOSDPreview, TQT_SIGNAL(positionChanged()), this, TQT_SLOT(slotPositionChanged()));
+    connect(m_pOSDPreview, TQ_SIGNAL(positionChanged()), this, TQ_SLOT(slotPositionChanged()));
 
-    connect( kcfg_OSDFont, TQT_SIGNAL(fontSelected(const TQFont&)), this, TQT_SLOT(slotUpdateFont(const TQFont&)));
+    connect( kcfg_OSDFont, TQ_SIGNAL(fontSelected(const TQFont&)), this, TQ_SLOT(slotUpdateFont(const TQFont&)));
 
     slotOSDEnabledChanged(kcfg_UseOSD->isChecked());
     slotCustomColorsChanged(kcfg_OSDUseCustomColors->isChecked());
@@ -61,12 +61,12 @@ OSD_Config::OSD_Config( TQWidget* parent, const char* name, WFlags fl )
     kcfg_OSDAlignment->hide();
 
     //Connect config page entries to control the OSDPreview
-    connect ( kcfg_UseOSD,  TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( slotOSDEnabledChanged(bool) ) );
-    connect ( kcfg_OSDUseCustomColors, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotCustomColorsChanged(bool)));
-    connect ( kcfg_OSDTextColor, TQT_SIGNAL(changed(const TQColor&)), this, TQT_SLOT(slotTextColorChanged(const TQColor&)));
-    connect ( kcfg_OSDBackgroundColor, TQT_SIGNAL(changed(const TQColor&)), this, TQT_SLOT(slotBackgroundColorChanged(const TQColor&)));
-    connect ( kcfg_OSDScreen, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotScreenChanged(int)));
-    connect ( kcfg_OSDDrawShadow, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotDrawShadowChanged(bool)));
+    connect ( kcfg_UseOSD,  TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( slotOSDEnabledChanged(bool) ) );
+    connect ( kcfg_OSDUseCustomColors, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotCustomColorsChanged(bool)));
+    connect ( kcfg_OSDTextColor, TQ_SIGNAL(changed(const TQColor&)), this, TQ_SLOT(slotTextColorChanged(const TQColor&)));
+    connect ( kcfg_OSDBackgroundColor, TQ_SIGNAL(changed(const TQColor&)), this, TQ_SLOT(slotBackgroundColorChanged(const TQColor&)));
+    connect ( kcfg_OSDScreen, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotScreenChanged(int)));
+    connect ( kcfg_OSDDrawShadow, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotDrawShadowChanged(bool)));
 }
 
 OSD_Config::~OSD_Config()
