@@ -19,7 +19,7 @@
 
 class SSLLabel : public TQLabel
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
         public:
