@@ -25,7 +25,7 @@ class TQStringList;
 
 class Theme_Config : public Theme_ConfigUI, public KonviSettingsPage
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
