@@ -16,15 +16,15 @@
 #include "valuelistviewitem.h"
 
 
-ValueListViewItem::ValueListViewItem(int newValue, KListView* parent, const TQString& label)
-: KListViewItem(parent,label)
+ValueListViewItem::ValueListViewItem(int newValue, TDEListView* parent, const TQString& label)
+: TDEListViewItem(parent,label)
 {
     m_value=newValue;
     enforceSortOrder();
 }
 
-ValueListViewItem::ValueListViewItem(int newValue, KListView* parent, TQListViewItem* after, const TQString& label)
-: KListViewItem(parent,after,label)
+ValueListViewItem::ValueListViewItem(int newValue, TDEListView* parent, TQListViewItem* after, const TQString& label)
+: TDEListViewItem(parent,after,label)
 {
     m_value=newValue;
     enforceSortOrder();
