@@ -43,7 +43,7 @@ namespace Konversation
 
 class ViewContainer : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
