@@ -20,7 +20,7 @@ class ChatWindow;
 
 class ViewTree : public TDEListView
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
